.. _xrst_table_of_contents-title:

Table of Contents
*****************
| :ref:`1<example-title>` Examples
|    :ref:`1.1<get_started-title>` Title: Getting Started
|    :ref:`1.2<literal_example-title>` Literal Command Example
|    :ref:`1.3<dir_example-title>` Dir Command Example
|    :ref:`1.4<toc_list_example-title>` toc_list Example Parent Page
|       :ref:`1.4.1<child_example_one-title>` First Child Example Page
|       :ref:`1.4.2<child_example_two-title>` Second Child Example Page
|    :ref:`1.5<spell_example-title>` Spell Command Example
|    :ref:`1.6<suspend_example-title>` Suspend Command Example
|    :ref:`1.7<code_example-title>` Code Command Example
|    :ref:`1.8<comment_example-title>` Comment Command Example
|    :ref:`1.9<comment_ch_example-title>` Comment Character Command Example
|    :ref:`1.10<heading_example-title>` Heading and Link Example
|    :ref:`1.11<indent_example-title>` Indent Example
|    :ref:`1.12<docstring_example-title>` Docstring Example
|    :ref:`1.13<configure_example-title>` Example Using TOML Configure File
|    :ref:`1.14<.readthedocs.yaml-title>` Example Read the Docs Configuration
|    :ref:`1.15<testExample-title>` Test Special Conditions
| :ref:`2<purpose-title>` Purpose of this Sphinx Wrapper
| :ref:`3<user-guide-title>` Extract Sphinx RST Files
|    :ref:`3.1<config_file-title>` Configuration File for xrst
|    :ref:`3.2<run_xrst-title>` Run Extract Sphinx RST And Sphinx
|    :ref:`3.3<commands-title>` Commands
|       :ref:`3.3.1<begin_cmd-title>` Begin and End Commands
|       :ref:`3.3.2<toc_cmd-title>` Table of Children Commands
|       :ref:`3.3.3<spell_cmd-title>` Spell Command
|       :ref:`3.3.4<suspend_cmd-title>` Suspend and Resume Commands
|       :ref:`3.3.5<code_cmd-title>` Code Command
|       :ref:`3.3.6<literal_cmd-title>` Literal Command
|       :ref:`3.3.7<dir_cmd-title>` Converting Sphinx Command File Names
|       :ref:`3.3.8<comment_cmd-title>` Comment Command
|       :ref:`3.3.9<comment_ch_cmd-title>` Comment Character Command
|    :ref:`3.4<automatic-title>` Automatic Processing
|       :ref:`3.4.1<indent-title>` Indentation
|       :ref:`3.4.2<heading_links-title>` Heading Cross Reference Links
|       :ref:`3.4.3<auto_file-title>` Automatically Generated Files
|    :ref:`3.5<wish_list-title>` Wish List
|    :ref:`3.6<release_notes-title>` xrst Release Notes By Year
|       :ref:`3.6.1<2023-title>` xrst Release Notes for 2023
|       :ref:`3.6.2<2022-title>` xrst Release Notes for 2022
|       :ref:`3.6.3<2021-title>` xrst Release Notes for 2021
| :ref:`4<module-title>` The xrst Module
|    :ref:`4.1<add_before_title-title>` If PDF, Add Page Number and Name to Title
|    :ref:`4.2<add_line_numbers-title>` Add Line Numbers to File Data
|    :ref:`4.3<auto_file_dev-title>` Create the automatically generated files
|    :ref:`4.4<check_input_files-title>` Check That Expected xrst Input Files Are Included
|    :ref:`4.5<check_page_name-title>` Check the rules for a page name
|    :ref:`4.6<check_syntax_error-title>` Check that an xrst command has been removed
|    :ref:`4.7<code_cmd_dev-title>` Process the xrst code commands for a page
|    :ref:`4.8<comment_cmd_dev-title>` Remove all comment commands
|    :ref:`4.9<dir_cmd_dev-title>` Convert File Names to be Relative to the RST Directory
|    :ref:`4.10<get_conf_dict-title>` Get Configuration Dictionary
|    :ref:`4.11<get_file_info-title>` Get information for all pages in a file
|    :ref:`4.12<get_spell_checker-title>` Get A Spell Checker Object
|    :ref:`4.13<literal_cmd_dev-title>` Process the literal commands in a page
|    :ref:`4.14<newline_indices-title>` Find index of all the newlines in a string
|    :ref:`4.15<next_heading-title>` Return location of the next heading in a page
|    :ref:`4.16<xrst.pattern-title>` The xrst.pattern Dictionary
|    :ref:`4.17<process_children-title>` Add child information to a page
|    :ref:`4.18<process_headings-title>` Add labels and index entries for headings
|    :ref:`4.19<remove_indent-title>` Remove indentation for a page
|    :ref:`4.20<remove_line_numbers-title>` Remove the number numbers
|    :ref:`4.21<rename_group-title>` Rename a Subset of a Group
|    :ref:`4.22<replace_spell-title>` Replace spelling commands
|    :ref:`4.23<spell_cmd_dev-title>` Process the spell command for a page
|    :ref:`4.24<sphinx_label-title>` Get Labels Declared Using Sphinx Commands
|    :ref:`4.25<start_end_file-title>` Convert literal command start, end from text to line numbers
|    :ref:`4.26<suspend_cmd_dev-title>` Remove text specified by suspend / resume pairs
|    :ref:`4.27<system_exit-title>` Form error message and exit
|    :ref:`4.28<table_of_contents-title>` Create the table of contents and Modify Titles
|    :ref:`4.29<temporary_file-title>` Write the temporary RST file for a page
|    :ref:`4.30<toc_cmd_dev-title>` Get file and page names for children of this page
